@@ -18,8 +18,6 @@
 import itertools
 import sys
 
-from openstack import exceptions as sdk_exceptions
-from openstack.network.v2 import quota as _quota
 from osc_lib.command import command
 from osc_lib import utils
 import six
@@ -167,7 +165,7 @@ class SetQuota(command.Command):
                     **volume_kwargs)
             if network_kwargs:
                 sys.stderr.write("Network quotas are ignored since quota class"
-                                 "is not supported.")
+                                 " is not supported.")
         else:
             project = utils.find_resource(
                 identity_client.projects,
@@ -182,36 +180,9 @@ class SetQuota(command.Command):
                     project,
                     **volume_kwargs)
             if network_kwargs:
-                if hasattr(_quota.Quota, 'allow_get'):
-                    # TODO(huanxuan): Remove this block once the fixed
-                    # SDK Quota class is the minimum required version.
-                    # This is expected to be SDK release 0.9.13
-                    res = network_client._get_resource(
-                        _quota.Quota, project, **network_kwargs)
-                    if any([res._body.dirty, res._header.dirty]):
-                        request = res._prepare_request(prepend_key=True)
-                        # remove the id in the body
-                        if 'id' in request.body[res.resource_key]:
-                            del request.body[res.resource_key]['id']
-                        if res.patch_update:
-                            response = network_client.session.patch(
-                                request.uri,
-                                endpoint_filter=res.service,
-                                json=request.body,
-                                headers=request.headers
-                            )
-                        else:
-                            response = network_client.session.put(
-                                request.uri,
-                                endpoint_filter=res.service,
-                                json=request.body,
-                                headers=request.headers
-                            )
-                        res._translate_response(response, has_body=True)
-                else:
-                    network_client.update_quota(
-                        project,
-                        **network_kwargs)
+                network_client.update_quota(
+                    project,
+                    **network_kwargs)
 
 
 class ShowQuota(command.ShowOne):
@@ -280,39 +251,7 @@ class ShowQuota(command.ShowOne):
             project = self._get_project(parsed_args)
             client = self.app.client_manager.network
             if parsed_args.default:
-                # TODO(dtroyer): Remove the top of this if block once the
-                #                fixed SDK QuotaDefault class is the minimum
-                #                required version.  This is expected to be
-                #                SDK release 0.9.13
-                if hasattr(_quota.QuotaDefault, 'project'):
-                    # hack 0.9.11+
-                    quotadef_obj = client._get_resource(
-                        _quota.QuotaDefault,
-                        project,
-                    )
-                    quotadef_obj.base_path = quotadef_obj.base_path % {
-                        'project': project,
-                    }
-                    try:
-                        network_quota = quotadef_obj.get(
-                            client.session,
-                            requires_id=False,
-                        )
-                    except sdk_exceptions.NotFoundException as e:
-                        raise sdk_exceptions.ResourceNotFound(
-                            message="No %s found for %s" %
-                                    (_quota.QuotaDefault.__name__, project),
-                            details=e.details,
-                            response=e.response,
-                            request_id=e.request_id,
-                            url=e.url,
-                            method=e.method,
-                            http_status=e.http_status,
-                            cause=e.cause,
-                        )
-                    # end hack-around
-                else:
-                    network_quota = client.get_quota_default(project)
+                network_quota = client.get_quota_default(project)
             else:
                 network_quota = client.get_quota(project)
             return network_quota
