@@ -30,6 +30,7 @@ from openstackclient.i18n import _
 from openstackclient.identity import common
 
 
+CONTAINER_CHOICES = ["ami", "ari", "aki", "bare", "docker", "ova", "ovf"]
 DEFAULT_CONTAINER_FORMAT = 'bare'
 DEFAULT_DISK_FORMAT = 'raw'
 DISK_CHOICES = ["ami", "ari", "aki", "vhd", "vmdk", "raw", "qcow2", "vhdx",
@@ -135,9 +136,13 @@ class CreateImage(command.ShowOne):
         parser.add_argument(
             "--container-format",
             default=DEFAULT_CONTAINER_FORMAT,
+            choices=CONTAINER_CHOICES,
             metavar="<container-format>",
-            help=_("Image container format "
-                   "(default: %s)") % DEFAULT_CONTAINER_FORMAT,
+            help=(_("Image container format. "
+                    "The supported options are: %(option_list)s. "
+                    "The default format is: %(default_opt)s") %
+                  {'option_list': ', '.join(CONTAINER_CHOICES),
+                   'default_opt': DEFAULT_CONTAINER_FORMAT})
         )
         parser.add_argument(
             "--disk-format",
@@ -159,12 +164,13 @@ class CreateImage(command.ShowOne):
             type=int,
             help=_("Minimum RAM size needed to boot image, in megabytes"),
         )
-        parser.add_argument(
+        source_group = parser.add_mutually_exclusive_group()
+        source_group.add_argument(
             "--file",
             metavar="<file>",
             help=_("Upload image from local file"),
         )
-        parser.add_argument(
+        source_group.add_argument(
             "--volume",
             metavar="<volume>",
             help=_("Create image from a volume"),
@@ -659,8 +665,9 @@ class SetImage(command.Command):
         parser.add_argument(
             "--container-format",
             metavar="<container-format>",
-            help=_("Image container format "
-                   "(default: %s)") % DEFAULT_CONTAINER_FORMAT,
+            choices=CONTAINER_CHOICES,
+            help=_("Image container format. The supported options are: %s") %
+            ', '.join(CONTAINER_CHOICES)
         )
         parser.add_argument(
             "--disk-format",
