@@ -12,6 +12,7 @@
 #
 
 """Subnet pool action implementations"""
+
 import copy
 import logging
 
@@ -22,17 +23,21 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
+from openstackclient.network import sdk_utils
 
 
 LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    columns = list(item.keys())
-    if 'tenant_id' in columns:
-        columns.remove('tenant_id')
-        columns.append('project_id')
-    return tuple(sorted(columns))
+    column_map = {
+        'default_prefix_length': 'default_prefixlen',
+        'is_shared': 'shared',
+        'maximum_prefix_length': 'max_prefixlen',
+        'minimum_prefix_length': 'min_prefixlen',
+        'tenant_id': 'project_id',
+    }
+    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 _formatters = {
@@ -134,8 +139,10 @@ def _add_default_options(parser):
     )
 
 
+# TODO(rtheis): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class CreateSubnetPool(command.ShowOne):
-    """Create subnet pool"""
+    _description = _("Create subnet pool")
 
     def get_parser(self, prog_name):
         parser = super(CreateSubnetPool, self).get_parser(prog_name)
@@ -184,13 +191,13 @@ class CreateSubnetPool(command.ShowOne):
         if "prefixes" not in attrs:
             attrs['prefixes'] = []
         obj = client.create_subnet_pool(**attrs)
-        columns = _get_columns(obj)
+        display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
-        return (columns, data)
+        return (display_columns, data)
 
 
 class DeleteSubnetPool(command.Command):
-    """Delete subnet pool(s)"""
+    _description = _("Delete subnet pool(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteSubnetPool, self).get_parser(prog_name)
@@ -213,8 +220,8 @@ class DeleteSubnetPool(command.Command):
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete subnet pool with "
-                          "name or ID '%(pool)s': %(e)s")
-                          % {'pool': pool, 'e': e})
+                          "name or ID '%(pool)s': %(e)s"),
+                          {'pool': pool, 'e': e})
 
         if result > 0:
             total = len(parsed_args.subnet_pool)
@@ -223,8 +230,10 @@ class DeleteSubnetPool(command.Command):
             raise exceptions.CommandError(msg)
 
 
+# TODO(rtheis): Use only the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class ListSubnetPool(command.Lister):
-    """List subnet pools"""
+    _description = _("List subnet pools")
 
     def get_parser(self, prog_name):
         parser = super(ListSubnetPool, self).get_parser(prog_name)
@@ -238,40 +247,42 @@ class ListSubnetPool(command.Lister):
         shared_group.add_argument(
             '--share',
             action='store_true',
-            help=_("List subnets shared between projects"),
+            help=_("List subnet pools shared between projects"),
         )
         shared_group.add_argument(
             '--no-share',
             action='store_true',
-            help=_("List subnets not shared between projects"),
+            help=_("List subnet pools not shared between projects"),
         )
         default_group = parser.add_mutually_exclusive_group()
         default_group.add_argument(
             '--default',
             action='store_true',
-            help=_("List subnets used as the default external subnet pool"),
+            help=_("List subnet pools used as the default external "
+                   "subnet pool"),
         )
         default_group.add_argument(
             '--no-default',
             action='store_true',
-            help=_("List subnets not used as the default external subnet pool")
+            help=_("List subnet pools not used as the default external "
+                   "subnet pool")
         )
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help=_("List subnets according to their project (name or ID)")
+            help=_("List subnet pools according to their project (name or ID)")
         )
         identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--name',
             metavar='<name>',
-            help=_("List only subnets of given name in output")
+            help=_("List only subnet pools of given name in output")
         )
         parser.add_argument(
             '--address-scope',
             metavar='<address-scope>',
-            help=_("List only subnets of given address scope (name or ID) "
-                   "in output")
+            help=_("List only subnet pools of given address scope "
+                   "(name or ID) in output")
         )
         return parser
 
@@ -281,8 +292,10 @@ class ListSubnetPool(command.Lister):
         filters = {}
         if parsed_args.share:
             filters['shared'] = True
+            filters['is_shared'] = True
         elif parsed_args.no_share:
             filters['shared'] = False
+            filters['is_shared'] = False
         if parsed_args.default:
             filters['is_default'] = True
         elif parsed_args.no_default:
@@ -294,6 +307,7 @@ class ListSubnetPool(command.Lister):
                 parsed_args.project_domain,
             ).id
             filters['tenant_id'] = project_id
+            filters['project_id'] = project_id
         if parsed_args.name is not None:
             filters['name'] = parsed_args.name
         if parsed_args.address_scope:
@@ -308,8 +322,8 @@ class ListSubnetPool(command.Lister):
         if parsed_args.long:
             headers += ('Default Prefix Length', 'Address Scope',
                         'Default Subnet Pool', 'Shared')
-            columns += ('default_prefixlen', 'address_scope_id',
-                        'is_default', 'shared')
+            columns += ('default_prefix_length', 'address_scope_id',
+                        'is_default', 'is_shared')
 
         return (headers,
                 (utils.get_item_properties(
@@ -318,8 +332,10 @@ class ListSubnetPool(command.Lister):
                 ) for s in data))
 
 
+# TODO(rtheis): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class SetSubnetPool(command.Command):
-    """Set subnet pool properties"""
+    _description = _("Set subnet pool properties")
 
     def get_parser(self, prog_name):
         parser = super(SetSubnetPool, self).get_parser(prog_name)
@@ -371,7 +387,7 @@ class SetSubnetPool(command.Command):
 
 
 class ShowSubnetPool(command.ShowOne):
-    """Display subnet pool details"""
+    _description = _("Display subnet pool details")
 
     def get_parser(self, prog_name):
         parser = super(ShowSubnetPool, self).get_parser(prog_name)
@@ -388,13 +404,13 @@ class ShowSubnetPool(command.ShowOne):
             parsed_args.subnet_pool,
             ignore_missing=False
         )
-        columns = _get_columns(obj)
+        display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
-        return (columns, data)
+        return (display_columns, data)
 
 
 class UnsetSubnetPool(command.Command):
-    """Unset subnet pool properties"""
+    _description = _("Unset subnet pool properties")
 
     def get_parser(self, prog_name):
         parser = super(UnsetSubnetPool, self).get_parser(prog_name)
