@@ -71,6 +71,10 @@ class TestNetworkV2(utils.TestCommand):
             token=fakes.AUTH_TOKEN,
         )
 
+        self.app.client_manager.sdk_connection = mock.Mock()
+        self.app.client_manager.sdk_connection.network = \
+            self.app.client_manager.network
+
         self.app.client_manager.identity = (
             identity_fakes_v3.FakeIdentityv3Client(
                 endpoint=fakes.AUTH_URL,
@@ -153,6 +157,31 @@ class FakeAddressScope(object):
         return mock.Mock(side_effect=address_scopes)
 
 
+class FakeAutoAllocatedTopology(object):
+    """Fake Auto Allocated Topology"""
+
+    @staticmethod
+    def create_one_topology(attrs=None):
+        attrs = attrs or {}
+
+        auto_allocated_topology_attrs = {
+            'id': 'network-id-' + uuid.uuid4().hex,
+            'tenant_id': 'project-id-' + uuid.uuid4().hex,
+        }
+
+        auto_allocated_topology_attrs.update(attrs)
+
+        auto_allocated_topology = fakes.FakeResource(
+            info=copy.deepcopy(auto_allocated_topology_attrs),
+            loaded=True)
+
+        auto_allocated_topology.project_id = auto_allocated_topology_attrs[
+            'tenant_id'
+        ]
+
+        return auto_allocated_topology
+
+
 class FakeAvailabilityZone(object):
     """Fake one or more network availability zones (AZs)."""
 
@@ -386,6 +415,69 @@ class FakeNetwork(object):
         return mock.Mock(side_effect=networks)
 
 
+class FakeNetworkFlavor(object):
+    """Fake Network Flavor."""
+
+    @staticmethod
+    def create_one_network_flavor(attrs=None):
+        """Create a fake network flavor.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object faking the network flavor
+        """
+        attrs = attrs or {}
+
+        fake_uuid = uuid.uuid4().hex
+        network_flavor_attrs = {
+            'description': 'network-flavor-description-' + fake_uuid,
+            'enabled': True,
+            'id': 'network-flavor-id-' + fake_uuid,
+            'name': 'network-flavor-name-' + fake_uuid,
+            'service_type': 'vpn',
+            'tenant_id': 'project-id-' + uuid.uuid4().hex,
+        }
+
+        # Overwrite default attributes.
+        network_flavor_attrs.update(attrs)
+
+        network_flavor = fakes.FakeResource(
+            info=copy.deepcopy(network_flavor_attrs),
+            loaded=True
+        )
+
+        network_flavor.project_id = network_flavor_attrs['tenant_id']
+        network_flavor.is_enabled = network_flavor_attrs['enabled']
+
+        return network_flavor
+
+    @staticmethod
+    def create_flavor(attrs=None, count=2):
+        """Create multiple fake network flavors.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param int count:
+            The number of network flavors to fake
+        :return:
+            A list of FakeResource objects faking the network falvors
+        """
+        network_flavors = []
+        for i in range(0, count):
+            network_flavors.append(
+                FakeNetworkFlavor.create_one_network_flavor(attrs)
+            )
+        return network_flavors
+
+    @staticmethod
+    def get_flavor(network_flavors=None, count=2):
+        """Get a list of flavors."""
+        if network_flavors is None:
+            network_flavors = (FakeNetworkFlavor.create_flavor(count))
+        return mock.Mock(side_effect=network_flavors)
+
+
 class FakeNetworkSegment(object):
     """Fake one or more network segments."""
 
@@ -470,13 +562,14 @@ class FakePort(object):
             'dns_assignment': [{}],
             'dns_name': 'dns-name-' + uuid.uuid4().hex,
             'extra_dhcp_opts': [{}],
-            'fixed_ips': [{}],
+            'fixed_ips': [{'ip_address': '10.0.0.3',
+                           'subnet_id': 'subnet-id-' + uuid.uuid4().hex}],
             'id': 'port-id-' + uuid.uuid4().hex,
             'mac_address': 'fa:16:3e:a9:4e:72',
             'name': 'port-name-' + uuid.uuid4().hex,
             'network_id': 'network-id-' + uuid.uuid4().hex,
             'port_security_enabled': True,
-            'security_groups': [],
+            'security_group_ids': [],
             'status': 'ACTIVE',
             'tenant_id': 'project-id-' + uuid.uuid4().hex,
         }
@@ -496,7 +589,7 @@ class FakePort(object):
         port.is_admin_state_up = port_attrs['admin_state_up']
         port.is_port_security_enabled = port_attrs['port_security_enabled']
         port.project_id = port_attrs['tenant_id']
-        port.security_group_ids = port_attrs['security_groups']
+        port.security_group_ids = port_attrs['security_group_ids']
 
         return port
 
@@ -1051,7 +1144,7 @@ class FakeSecurityGroupRule(object):
             'description': 'security-group-rule-description-' +
                            uuid.uuid4().hex,
             'direction': 'ingress',
-            'ethertype': 'IPv4',
+            'ether_type': 'IPv4',
             'id': 'security-group-rule-id-' + uuid.uuid4().hex,
             'port_range_max': None,
             'port_range_min': None,
@@ -1322,6 +1415,52 @@ class FakeNetworkMeter(object):
         return mock.Mock(side_effect=meter)
 
 
+class FakeNetworkMeterRule(object):
+    """Fake metering rule"""
+
+    @staticmethod
+    def create_one_rule(attrs=None):
+        """Create one meter rule"""
+        attrs = attrs or {}
+
+        meter_rule_attrs = {
+            'id': 'meter-label-rule-id-' + uuid.uuid4().hex,
+            'direction': 'ingress',
+            'excluded': False,
+            'metering_label_id': 'meter-label-id-' + uuid.uuid4().hex,
+            'remote_ip_prefix': '10.0.0.0/24',
+            'tenant_id': 'project-id-' + uuid.uuid4().hex,
+        }
+
+        meter_rule_attrs.update(attrs)
+
+        meter_rule = fakes.FakeResource(
+            info=copy.deepcopy(meter_rule_attrs),
+            loaded=True)
+
+        meter_rule.project_id = meter_rule_attrs['tenant_id']
+
+        return meter_rule
+
+    @staticmethod
+    def create_meter_rule(attrs=None, count=2):
+        """Create multiple meter rules"""
+
+        meter_rules = []
+        for i in range(0, count):
+            meter_rules.append(FakeNetworkMeterRule.
+                               create_one_rule(attrs))
+        return meter_rules
+
+    @staticmethod
+    def get_meter_rule(meter_rule=None, count=2):
+        """Get a list of meter rules"""
+        if meter_rule is None:
+            meter_rule = (FakeNetworkMeterRule.
+                          create_meter_rule(count))
+        return mock.Mock(side_effect=meter_rule)
+
+
 class FakeSubnetPool(object):
     """Fake one or more subnet pools."""
 
