@@ -60,8 +60,9 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         network_fakes.FakeSecurityGroup.create_one_security_group()
 
     expected_columns = (
+        'description',
         'direction',
-        'ethertype',
+        'ether_type',
         'id',
         'port_range_max',
         'port_range_min',
@@ -81,8 +82,9 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.network.create_security_group_rule = mock.Mock(
             return_value=self._security_group_rule)
         self.expected_data = (
+            self._security_group_rule.description,
             self._security_group_rule.direction,
-            self._security_group_rule.ethertype,
+            self._security_group_rule.ether_type,
             self._security_group_rule.id,
             self._security_group_rule.port_range_max,
             self._security_group_rule.port_range_min,
@@ -119,6 +121,15 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.assertRaises(tests_utils.ParserException,
                           self.check_parser, self.cmd, arglist, [])
 
+    def test_create_all_remote_options(self):
+        arglist = [
+            '--remote-ip', '10.10.0.0/24',
+            '--remote-group', self._security_group.id,
+            self._security_group.id,
+        ]
+        self.assertRaises(tests_utils.ParserException,
+                          self.check_parser, self.cmd, arglist, [])
+
     def test_create_bad_ethertype(self):
         arglist = [
             '--ethertype', 'foo',
@@ -173,7 +184,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_max': self._security_group_rule.port_range_max,
             'port_range_min': self._security_group_rule.port_range_min,
             'protocol': self._security_group_rule.protocol,
@@ -205,7 +216,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'protocol': self._security_group_rule.protocol,
             'remote_ip_prefix': self._security_group_rule.remote_ip_prefix,
             'security_group_id': self._security_group.id,
@@ -213,7 +224,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.assertEqual(self.expected_columns, columns)
         self.assertEqual(self.expected_data, data)
 
-    def test_create_source_group(self):
+    def test_create_remote_group(self):
         self._setup_security_group_rule({
             'port_range_max': 22,
             'port_range_min': 22,
@@ -238,7 +249,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_max': self._security_group_rule.port_range_max,
             'port_range_min': self._security_group_rule.port_range_min,
             'protocol': self._security_group_rule.protocol,
@@ -248,6 +259,34 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.assertEqual(self.expected_columns, columns)
         self.assertEqual(self.expected_data, data)
 
+    def test_create_source_group(self):
+        self._setup_security_group_rule({
+            'remote_group_id': self._security_group.id,
+        })
+        arglist = [
+            '--ingress',
+            '--src-group', self._security_group.name,
+            self._security_group.id,
+        ]
+        verifylist = [
+            ('ingress', True),
+            ('src_group', self._security_group.name),
+            ('group', self._security_group.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_security_group_rule.assert_called_once_with(**{
+            'direction': self._security_group_rule.direction,
+            'ethertype': self._security_group_rule.ether_type,
+            'protocol': self._security_group_rule.protocol,
+            'remote_group_id': self._security_group_rule.remote_group_id,
+            'security_group_id': self._security_group.id,
+        })
+        self.assertEqual(self.expected_columns, columns)
+        self.assertEqual(self.expected_data, data)
+
     def test_create_source_ip(self):
         self._setup_security_group_rule({
             'protocol': 'icmp',
@@ -269,7 +308,36 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
+            'protocol': self._security_group_rule.protocol,
+            'remote_ip_prefix': self._security_group_rule.remote_ip_prefix,
+            'security_group_id': self._security_group.id,
+        })
+        self.assertEqual(self.expected_columns, columns)
+        self.assertEqual(self.expected_data, data)
+
+    def test_create_remote_ip(self):
+        self._setup_security_group_rule({
+            'protocol': 'icmp',
+            'remote_ip_prefix': '10.0.2.0/24',
+        })
+        arglist = [
+            '--protocol', self._security_group_rule.protocol,
+            '--remote-ip', self._security_group_rule.remote_ip_prefix,
+            self._security_group.id,
+        ]
+        verifylist = [
+            ('protocol', self._security_group_rule.protocol),
+            ('remote_ip', self._security_group_rule.remote_ip_prefix),
+            ('group', self._security_group.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_security_group_rule.assert_called_once_with(**{
+            'direction': self._security_group_rule.direction,
+            'ethertype': self._security_group_rule.ether_type,
             'protocol': self._security_group_rule.protocol,
             'remote_ip_prefix': self._security_group_rule.remote_ip_prefix,
             'security_group_id': self._security_group.id,
@@ -280,7 +348,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
     def test_create_network_options(self):
         self._setup_security_group_rule({
             'direction': 'egress',
-            'ethertype': 'IPv6',
+            'ether_type': 'IPv6',
             'port_range_max': 443,
             'port_range_min': 443,
             'protocol': '6',
@@ -290,7 +358,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         arglist = [
             '--dst-port', str(self._security_group_rule.port_range_min),
             '--egress',
-            '--ethertype', self._security_group_rule.ethertype,
+            '--ethertype', self._security_group_rule.ether_type,
             '--project', self.project.name,
             '--project-domain', self.domain.name,
             '--protocol', self._security_group_rule.protocol,
@@ -300,7 +368,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
             ('dst_port', (self._security_group_rule.port_range_min,
                           self._security_group_rule.port_range_max)),
             ('egress', True),
-            ('ethertype', self._security_group_rule.ethertype),
+            ('ethertype', self._security_group_rule.ether_type),
             ('project', self.project.name),
             ('project_domain', self.domain.name),
             ('protocol', self._security_group_rule.protocol),
@@ -312,7 +380,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_max': self._security_group_rule.port_range_max,
             'port_range_min': self._security_group_rule.port_range_min,
             'protocol': self._security_group_rule.protocol,
@@ -376,7 +444,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_min': self._security_group_rule.port_range_min,
             'protocol': self._security_group_rule.protocol,
             'remote_ip_prefix': self._security_group_rule.remote_ip_prefix,
@@ -387,7 +455,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
     def test_create_ipv6_icmp_type_code(self):
         self._setup_security_group_rule({
-            'ethertype': 'IPv6',
+            'ether_type': 'IPv6',
             'port_range_min': 139,
             'port_range_max': 2,
             'protocol': 'ipv6-icmp',
@@ -411,7 +479,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_min': self._security_group_rule.port_range_min,
             'port_range_max': self._security_group_rule.port_range_max,
             'protocol': self._security_group_rule.protocol,
@@ -422,7 +490,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
     def test_create_icmpv6_type(self):
         self._setup_security_group_rule({
-            'ethertype': 'IPv6',
+            'ether_type': 'IPv6',
             'port_range_min': 139,
             'protocol': 'icmpv6',
         })
@@ -444,7 +512,7 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
 
         self.network.create_security_group_rule.assert_called_once_with(**{
             'direction': self._security_group_rule.direction,
-            'ethertype': self._security_group_rule.ethertype,
+            'ethertype': self._security_group_rule.ether_type,
             'port_range_min': self._security_group_rule.port_range_min,
             'protocol': self._security_group_rule.protocol,
             'security_group_id': self._security_group.id,
@@ -452,6 +520,33 @@ class TestCreateSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.assertEqual(self.expected_columns, columns)
         self.assertEqual(self.expected_data, data)
 
+    def test_create_with_description(self):
+        self._setup_security_group_rule({
+            'description': 'Setting SGR',
+        })
+        arglist = [
+            '--description', self._security_group_rule.description,
+            self._security_group.id,
+        ]
+        verifylist = [
+            ('description', self._security_group_rule.description),
+            ('group', self._security_group.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_security_group_rule.assert_called_once_with(**{
+            'description': self._security_group_rule.description,
+            'direction': self._security_group_rule.direction,
+            'ethertype': self._security_group_rule.ether_type,
+            'protocol': self._security_group_rule.protocol,
+            'remote_ip_prefix': self._security_group_rule.remote_ip_prefix,
+            'security_group_id': self._security_group.id,
+        })
+        self.assertEqual(self.expected_columns, columns)
+        self.assertEqual(self.expected_data, data)
+
 
 class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
@@ -498,6 +593,15 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertRaises(tests_utils.ParserException,
                           self.check_parser, self.cmd, arglist, [])
 
+    def test_create_all_remote_options(self):
+        arglist = [
+            '--remote-ip', '10.10.0.0/24',
+            '--remote-group', self._security_group.id,
+            self._security_group.id,
+        ]
+        self.assertRaises(tests_utils.ParserException,
+                          self.check_parser, self.cmd, arglist, [])
+
     def test_create_bad_protocol(self):
         arglist = [
             '--protocol', 'foo',
@@ -588,6 +692,38 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_columns, columns)
         self.assertEqual(expected_data, data)
 
+    def test_create_remote_group(self):
+        expected_columns, expected_data = self._setup_security_group_rule({
+            'from_port': 22,
+            'to_port': 22,
+            'group': {'name': self._security_group.name},
+        })
+        arglist = [
+            '--dst-port', str(self._security_group_rule.from_port),
+            '--remote-group', self._security_group.name,
+            self._security_group.id,
+        ]
+        verifylist = [
+            ('dst_port', (self._security_group_rule.from_port,
+                          self._security_group_rule.to_port)),
+            ('remote_group', self._security_group.name),
+            ('group', self._security_group.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.compute.security_group_rules.create.assert_called_once_with(
+            self._security_group.id,
+            self._security_group_rule.ip_protocol,
+            self._security_group_rule.from_port,
+            self._security_group_rule.to_port,
+            self._security_group_rule.ip_range['cidr'],
+            self._security_group.id,
+        )
+        self.assertEqual(expected_columns, columns)
+        self.assertEqual(expected_data, data)
+
     def test_create_source_ip(self):
         expected_columns, expected_data = self._setup_security_group_rule({
             'ip_protocol': 'icmp',
@@ -620,6 +756,38 @@ class TestCreateSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
         self.assertEqual(expected_columns, columns)
         self.assertEqual(expected_data, data)
 
+    def test_create_remote_ip(self):
+        expected_columns, expected_data = self._setup_security_group_rule({
+            'ip_protocol': 'icmp',
+            'from_port': -1,
+            'to_port': -1,
+            'ip_range': {'cidr': '10.0.2.0/24'},
+        })
+        arglist = [
+            '--protocol', self._security_group_rule.ip_protocol,
+            '--remote-ip', self._security_group_rule.ip_range['cidr'],
+            self._security_group.id,
+        ]
+        verifylist = [
+            ('protocol', self._security_group_rule.ip_protocol),
+            ('remote_ip', self._security_group_rule.ip_range['cidr']),
+            ('group', self._security_group.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.compute.security_group_rules.create.assert_called_once_with(
+            self._security_group.id,
+            self._security_group_rule.ip_protocol,
+            self._security_group_rule.from_port,
+            self._security_group_rule.to_port,
+            self._security_group_rule.ip_range['cidr'],
+            None,
+        )
+        self.assertEqual(expected_columns, columns)
+        self.assertEqual(expected_data, data)
+
     def test_create_proto_option(self):
         expected_columns, expected_data = self._setup_security_group_rule({
             'ip_protocol': 'icmp',
@@ -871,7 +1039,7 @@ class TestListSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
             security_group_rule._format_network_port_range(
                 _security_group_rule),
             _security_group_rule.direction,
-            _security_group_rule.ethertype,
+            _security_group_rule.ether_type,
             _security_group_rule.remote_group_id,
         ))
         expected_data_no_group.append((
@@ -942,6 +1110,60 @@ class TestListSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         self.assertEqual(self.expected_columns_no_group, columns)
         self.assertEqual(self.expected_data_no_group, list(data))
 
+    def test_list_with_protocol(self):
+        self._security_group_rule_tcp.port_range_min = 80
+        arglist = [
+            '--protocol', 'tcp',
+        ]
+        verifylist = [
+            ('protocol', 'tcp'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.security_group_rules.assert_called_once_with(**{
+            'protocol': 'tcp',
+        })
+        self.assertEqual(self.expected_columns_no_group, columns)
+        self.assertEqual(self.expected_data_no_group, list(data))
+
+    def test_list_with_ingress(self):
+        self._security_group_rule_tcp.port_range_min = 80
+        arglist = [
+            '--ingress',
+        ]
+        verifylist = [
+            ('ingress', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.security_group_rules.assert_called_once_with(**{
+            'direction': 'ingress',
+        })
+        self.assertEqual(self.expected_columns_no_group, columns)
+        self.assertEqual(self.expected_data_no_group, list(data))
+
+    def test_list_with_wrong_egress(self):
+        self._security_group_rule_tcp.port_range_min = 80
+        arglist = [
+            '--egress',
+        ]
+        verifylist = [
+            ('egress', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.security_group_rules.assert_called_once_with(**{
+            'direction': 'egress',
+        })
+        self.assertEqual(self.expected_columns_no_group, columns)
+        self.assertEqual(self.expected_data_no_group, list(data))
+
 
 class TestListSecurityGroupRuleCompute(TestSecurityGroupRuleCompute):
 
@@ -1075,8 +1297,9 @@ class TestShowSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
         network_fakes.FakeSecurityGroupRule.create_one_security_group_rule()
 
     columns = (
+        'description',
         'direction',
-        'ethertype',
+        'ether_type',
         'id',
         'port_range_max',
         'port_range_min',
@@ -1088,8 +1311,9 @@ class TestShowSecurityGroupRuleNetwork(TestSecurityGroupRuleNetwork):
     )
 
     data = (
+        _security_group_rule.description,
         _security_group_rule.direction,
-        _security_group_rule.ethertype,
+        _security_group_rule.ether_type,
         _security_group_rule.id,
         _security_group_rule.port_range_max,
         _security_group_rule.port_range_min,
