@@ -23,115 +23,6 @@ from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
 from openstackclient.tests.unit import utils
 
 
-volume_id = 'vvvvvvvv-vvvv-vvvv-vvvvvvvv'
-volume_name = 'nigel'
-volume_description = 'Nigel Tufnel'
-volume_status = 'available'
-volume_size = 120
-volume_type = 'to-eleven'
-volume_zone = 'stonehenge'
-volume_metadata = {
-    'Alpha': 'a',
-    'Beta': 'b',
-    'Gamma': 'g',
-}
-volume_metadata_str = "Alpha='a', Beta='b', Gamma='g'"
-
-VOLUME = {
-    'id': volume_id,
-    'display_name': volume_name,
-    'display_description': volume_description,
-    'size': volume_size,
-    'status': volume_status,
-    'attach_status': 'detached',
-    'availability_zone': volume_zone,
-    'volume_type': volume_type,
-    'metadata': volume_metadata,
-}
-
-extension_name = 'SchedulerHints'
-extension_namespace = 'http://docs.openstack.org/'\
-    'block-service/ext/scheduler-hints/api/v2'
-extension_description = 'Pass arbitrary key/value'\
-    'pairs to the scheduler.'
-extension_updated = '2014-02-07T12:00:0-00:00'
-extension_alias = 'OS-SCH-HNT'
-extension_links = '[{"href":'\
-    '"https://github.com/openstack/block-api", "type":'\
-    ' "text/html", "rel": "describedby"}]'
-
-EXTENSION = {
-    'name': extension_name,
-    'namespace': extension_namespace,
-    'description': extension_description,
-    'updated': extension_updated,
-    'alias': extension_alias,
-    'links': extension_links,
-}
-
-# NOTE(dtroyer): duplicating here the minimum image info needed to test
-#                volume create --image until circular references can be
-#                avoided by refactoring the test fakes.
-
-image_id = 'im1'
-image_name = 'graven'
-
-
-IMAGE = {
-    'id': image_id,
-    'name': image_name,
-}
-
-type_id = "5520dc9e-6f9b-4378-a719-729911c0f407"
-type_name = "fake-lvmdriver-1"
-
-TYPE = {
-    'id': type_id,
-    'name': type_name
-}
-
-qos_id = '6f2be1de-997b-4230-b76c-a3633b59e8fb'
-qos_consumer = 'front-end'
-qos_default_consumer = 'both'
-qos_name = "fake-qos-specs"
-qos_specs = {
-    'foo': 'bar',
-    'iops': '9001'
-}
-qos_association = {
-    'association_type': 'volume_type',
-    'name': type_name,
-    'id': type_id
-}
-
-QOS = {
-    'id': qos_id,
-    'consumer': qos_consumer,
-    'name': qos_name
-}
-
-QOS_DEFAULT_CONSUMER = {
-    'id': qos_id,
-    'consumer': qos_default_consumer,
-    'name': qos_name
-}
-
-QOS_WITH_SPECS = {
-    'id': qos_id,
-    'consumer': qos_consumer,
-    'name': qos_name,
-    'specs': qos_specs
-}
-
-QOS_WITH_ASSOCIATIONS = {
-    'id': qos_id,
-    'consumer': qos_consumer,
-    'name': qos_name,
-    'specs': qos_specs,
-    'associations': [qos_association]
-}
-
-
 class FakeTransfer(object):
     """Fake one or more Transfer."""
 
@@ -473,6 +364,9 @@ class FakeVolumev1Client(object):
         self.qos_specs.resource_class = fakes.FakeResource(None, {})
         self.volume_types = mock.Mock()
         self.volume_types.resource_class = fakes.FakeResource(None, {})
+        self.volume_encryption_types = mock.Mock()
+        self.volume_encryption_types.resource_class = (
+            fakes.FakeResource(None, {}))
         self.transfers = mock.Mock()
         self.transfers.resource_class = fakes.FakeResource(None, {})
         self.volume_snapshots = mock.Mock()
@@ -579,6 +473,34 @@ class FakeType(object):
 
         return mock.Mock(side_effect=types)
 
+    @staticmethod
+    def create_one_encryption_type(attrs=None):
+        """Create a fake encryption type.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object with volume_type_id etc.
+        """
+        attrs = attrs or {}
+
+        # Set default attributes.
+        encryption_info = {
+            "volume_type_id": 'type-id-' + uuid.uuid4().hex,
+            'provider': 'LuksEncryptor',
+            'cipher': None,
+            'key_size': None,
+            'control_location': 'front-end',
+        }
+
+        # Overwrite default attributes.
+        encryption_info.update(attrs)
+
+        encryption_type = fakes.FakeResource(
+            info=copy.deepcopy(encryption_info),
+            loaded=True)
+        return encryption_type
+
 
 class FakeSnapshot(object):
     """Fake one or more snapshot."""
